@@ -71,6 +71,7 @@ namespace Amarok
         protected:
             virtual void resizeEvent( QResizeEvent* );
             virtual void mousePressEvent( QMouseEvent* );
+            virtual void contextMenuEvent( QContextMenuEvent* );
         private:
             void changeAnalyzer();
             QWidget *m_child;
@@ -119,6 +120,8 @@ namespace Amarok
 
             virtual void setIcons( QStringList icons );
 
+            virtual QString currentText() const;
+
             QStringList icons() const;
 
             QString currentIcon() const;
