@@ -34,27 +34,31 @@
 #include <kwin.h>
 
 
-namespace Amarok {
-    void coverContextMenu( QWidget *parent, QPoint point, const QString &artist, const QString &album, bool showCoverManager ) {
+void
+Amarok::coverContextMenu( QWidget *parent, QPoint point, const QString &artist, const QString &album, bool showCoverManager )
+{
         KPopupMenu menu;
         enum { SHOW, FETCH, CUSTOM, DELETE, MANAGER };
 
         menu.insertTitle( i18n( "Cover Image" ) );
 
         menu.insertItem( SmallIconSet( Amarok::icon( "zoom" ) ), i18n( "&Show Fullsize" ), SHOW );
-        menu.insertItem( SmallIconSet( Amarok::icon( "download" ) ), i18n( "&Fetch From amazon.%1" ).arg(CoverManager::amazonTld()), FETCH );
+        menu.insertItem( SmallIconSet( Amarok::icon( "download" ) ), i18n( "&Fetch From amazon.%1" ).arg( CoverManager::amazonTld() ), FETCH );
         menu.insertItem( SmallIconSet( Amarok::icon( "files" ) ), i18n( "Set &Custom Cover" ), CUSTOM );
+        bool disable = !album.isEmpty(); // disable setting covers for unknown albums
+        menu.setItemEnabled( FETCH, disable );
+        menu.setItemEnabled( CUSTOM, disable );
         menu.insertSeparator();
 
-        menu.insertItem( SmallIconSet( Amarok::icon( "remove" ) ), i18n("&Unset Cover"), DELETE );
+        menu.insertItem( SmallIconSet( Amarok::icon( "remove" ) ), i18n( "&Unset Cover" ), DELETE );
         if ( showCoverManager ) {
             menu.insertSeparator();
-            menu.insertItem( SmallIconSet( Amarok::icon( "covermanager" ) ), i18n( "Cover Manager" ), MANAGER );
+            menu.insertItem( SmallIconSet( Amarok::icon( "covermanager" ) ), i18n( "Cover &Manager" ), MANAGER );
         }
         #ifndef AMAZON_SUPPORT
         menu.setItemEnabled( FETCH, false );
         #endif
-        bool disable = !CollectionDB::instance()->albumImage( artist, album, 0 ).contains( "nocover" );
+        disable = !CollectionDB::instance()->albumImage( artist, album, 0 ).contains( "nocover" );
         menu.setItemEnabled( SHOW, disable );
         menu.setItemEnabled( DELETE, disable );
 
@@ -105,7 +109,6 @@ namespace Amarok {
             CoverManager::showOnce( album );
             break;
         }
-    }
 }
 
 
@@ -190,8 +193,8 @@ CoverFetcher::startFetch()
 {
     DEBUG_FUNC_INFO
 
-    // Static license Key. Thanks muesli ;-)
-    const QString LICENSE( "D1URM11J3F2CEH" );
+    // Static license Key. Thanks hydrogen ;-)
+    const QString LICENSE( "11ZKJS8X1ETSTJ6MT802" );
 
     // reset all values
     m_coverAmazonUrls.clear();
@@ -211,29 +214,24 @@ CoverFetcher::startFetch()
 
     // '&' breaks searching
     query.remove('&');
+    
+    QString locale = AmarokConfig::amazonLocale();
+    QString tld;
 
-    // Bug 97901: Import cover from amazon france doesn't work properly
-    // (we have to set "mode=music-fr" instead of "mode=music")
-    QString musicMode = AmarokConfig::amazonLocale() == "fr" ? "music-fr" : "music";
-    //Amazon Japan isn't on xml.amazon.com
-    QString tld = "com";
-    int mibenum = 4;  // latin1
-    if( AmarokConfig::amazonLocale() == "jp" ) {
-        musicMode = "music-jp";
-        tld = "co.jp";
-        mibenum = 106;  // utf-8
-    }
-    else if( AmarokConfig::amazonLocale() == "ca" )
-        musicMode = "music-ca";
+    if( locale == "us" )
+        tld = "com";
+    else if( locale =="uk" )
+        tld = "co.uk";
+    else
+        tld = locale;
+
+    int mibenum = 106; // utf-8
 
     QString url;
-    // changed to type=lite because it makes less traffic
-    url = "http://xml.amazon." + tld
-        + "/onca/xml3?t=webservices-20&dev-t=" + LICENSE
-        + "&KeywordSearch=" + KURL::encode_string_no_slash( query, mibenum )
-        + "&mode=" + musicMode
-        + "&type=lite&locale=" + AmarokConfig::amazonLocale()
-        + "&page=1&f=xml";
+    url = "http://ecs.amazonaws." + tld
+        + "/onca/xml?Service=AWSECommerceService&Version=2007-10-29&Operation=ItemSearch&AssociateTag=webservices-20&AWSAccessKeyId=" + LICENSE
+        + "&Keywords=" + KURL::encode_string_no_slash( query, mibenum )
+        + "&SearchIndex=Music&ResponseGroup=Small,Images";
     debug() << url << endl;
 
     KIO::TransferJob* job = KIO::storedGet( url, false, false );
@@ -270,62 +268,106 @@ CoverFetcher::finishedXmlFetch( KIO::Job *job ) //SLOT
         return;
     }
 
-    const QDomNode details = doc.documentElement().namedItem( "Details" );
-
-    // the url for the Amazon product info page
-    m_amazonURL = details.attributes().namedItem( "url" ).toAttr().value();
-    QDomNode it = details.firstChild();
-    while ( !it.isNull() ) {
-        if ( it.isElement() ) {
-            QDomElement e = it.toElement();
-            if(e.tagName()=="Asin")
-            {
-                m_asin = e.firstChild().toText().data();
-                debug() << "setting the ASIN as" << m_asin << endl;
-                break;
-            }
-        }
-        it = it.nextSibling();
-    }
-
-    QString size = "ImageUrl";
-    switch( m_size ) {
-        case 0:  size += "Small";  break;
-        case 1:  size += "Medium"; break;
-        default: size += "Large";  break;
-    }
-
-    debug() << "Fetching size: " << size << endl;
-
     m_coverAsins.clear();
     m_coverAmazonUrls.clear();
     m_coverUrls.clear();
     m_coverNames.clear();
-    for( QDomNode node = details; !node.isNull(); node = node.nextSibling() ) {
-        QString amazonUrl = node.attributes().namedItem( "url" ).toAttr().value();
-        QString coverUrl = node.namedItem( size ).firstChild().toText().nodeValue();
-        QString asin = node.namedItem( "Asin" ).firstChild().toText().nodeValue();
-        QString name = node.namedItem( "ProductName" ).firstChild().toText().nodeValue();
 
-    const QDomNode  artists = node.namedItem("Artists");
-    // in most cases Amazon only sends one Artit in Artits
-    QString artist="";
-    if (!artists.isNull()) artist = artists.namedItem( "Artist" ).firstChild().toText().nodeValue();
+    // the url for the Amazon product info page
+    const QDomNodeList list = doc.documentElement().namedItem( "Items" ).childNodes();
 
-        debug() << "name:" << name << " artist:" << artist << " url:" << coverUrl << endl;
-
-        if( !coverUrl.isEmpty() )
+    for(int i = 0; i < list.count(); i++ )
+    {
+        QDomNode n = list.item( i );
+        if( n.isElement() && n.nodeName() == "IsValid" )
         {
-            m_coverAmazonUrls += amazonUrl;
-            m_coverAsins += asin;
-            m_coverUrls += coverUrl;
-            m_coverNames += artist + " - " + name;
+            if( n.toElement().text() == "False" )
+            {
+                warning() << "The XML Is Invalid!";
+                return;
+            }
+        }
+        else if( list.item( i ).nodeName() == "Item" )
+        {
+            const QDomNode node = list.item( i );
+            parseItemNode( node );
         }
     }
-
     attemptAnotherFetch();
 }
 
+void CoverFetcher::parseItemNode( const QDomNode &node )
+{
+    QDomNode it = node.firstChild();
+
+    QString size;
+    switch( m_size )
+    {
+        case 0:  size = "Small";  break;
+        case 1:  size = "Medium"; break;
+        default: size = "Large";  break;
+    }
+    size += "Image";
+
+    while ( !it.isNull() ) {
+        if ( it.isElement() ) {
+            QDomElement e = it.toElement();
+            if(e.tagName()=="ASIN")
+            {
+                m_asin = e.text();
+                m_coverAsins += m_asin;
+            }
+            else if(e.tagName() == "DetailPageURL" )
+            {
+                m_amazonURL = e.text();
+                m_coverAmazonUrls += m_amazonURL;
+            }
+            else if( e.tagName() == size )
+            {
+                QDomNode subIt = e.firstChild();
+                while( !subIt.isNull() )
+                {
+                    if( subIt.isElement() )
+                    {
+                        QDomElement subE = subIt.toElement();
+                        if( subE.tagName() == "URL" )
+                        {
+                            const QString coverUrl = subE.text();
+                            m_coverUrls += coverUrl;
+                            break;
+                        }
+                    }
+                    subIt = subIt.nextSibling();
+                }
+            }
+            else if( e.tagName() == "ItemAttributes" )
+            {
+                QDomNodeList nodes = e.childNodes();
+                QDomNode iter;
+                QString artist;
+                QString album;
+                for( int i = 0; i < nodes.count(); i++ )
+                {
+                    iter = nodes.item( i );
+
+                    if( iter.isElement() )
+                    {
+                        if( iter.nodeName() == "Artist" )
+                        {
+                            artist = iter.toElement().text();
+                        }
+                        else if( iter.nodeName() == "Title" )
+                        {
+                            album = iter.toElement().text();
+                        }
+                    }
+                }
+                m_coverNames += QString( artist + " - " + album );
+            }
+        }
+        it = it.nextSibling();
+    }
+}
 
 void
 CoverFetcher::finishedImageFetch( KIO::Job *job ) //SLOT
