@@ -36,7 +36,7 @@ public:
    virtual void play_finished(int playerIndex);
    virtual const Engine::Scope &scope();
 
-   virtual amaroK::PluginConfig *configure() const;
+   virtual Amarok::PluginConfig *configure() const;
 
    virtual void onContacting(const char *host);
    virtual void onBuffering(int pcnt);
@@ -48,6 +48,7 @@ public slots:
    virtual bool play( uint = 0 );
    virtual void stop();
    virtual void pause();
+   virtual void unpause();
    virtual void seek( uint );
 
    virtual void setEqualizerEnabled( bool );
@@ -103,6 +104,7 @@ private:
    {
       unsigned long m_startfadetime;
       bool m_fadeactive;
+      bool m_stopfade;
    } m_pfade[2];
 
    void cleanup();
